==> codelite-2.9.0.4684.tar.gz: codelite-2.9.0.4684/LiteEditor/editorsettingsfolding.cpp <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah
// file name            : editorsettingsfolding.cpp
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#include "globals.h"
#include "editorsettingsfolding.h"

EditorSettingsFolding::EditorSettingsFolding( wxWindow* parent )
		: EditorSettingsFoldingBase( parent )
		, TreeBookNode<EditorSettingsFolding>()
{
	OptionsConfigPtr options = EditorConfigST::Get()->GetOptions();
	m_displayMargin->SetValue(options->GetDisplayFoldMargin());
	m_underlineFolded->SetValue(options->GetUnderlineFoldLine());
	m_foldPreprocessors->SetValue(options->GetFoldPreprocessor());
	m_foldCompact->SetValue(options->GetFoldCompact());
	m_foldElse->SetValue(options->GetFoldAtElse());
	
	const wxString FoldStyles[] = { wxT("Simple"), wxT("Arrows"), wxT("Arrows with Background Colour"), wxT("Simple with Background Colour"), 
									  wxT("Flatten Tree Square Headers"), wxT("Flatten Tree Circular Headers") };
	m_stringManager.AddStrings(sizeof(FoldStyles)/sizeof(wxString), FoldStyles, options->GetFoldStyle(), m_foldStyle);

	m_colourPicker->SetColour(options->GetFoldBgColour());
}


void EditorSettingsFolding::Save(OptionsConfigPtr options)
{
	options->SetDisplayFoldMargin(m_displayMargin->GetValue());
	options->SetUnderlineFoldLine(m_underlineFolded->GetValue());
	options->SetFoldPreprocessor(m_foldPreprocessors->GetValue());
	options->SetFoldCompact(m_foldCompact->GetValue());
	options->SetFoldAtElse(m_foldElse->GetValue());
	
	// Get the foldstyle selection, unlocalised
	wxString foldStyle = m_stringManager.GetStringSelection();
	if (foldStyle.IsEmpty()) {
		foldStyle = wxT("Arrows");
	}
	options->SetFoldStyle(foldStyle);
	
	options->SetFoldBgColour(m_colourPicker->GetColour());
}

void EditorSettingsFolding::OnFoldColourUI(wxUpdateUIEvent& e)
{
	e.Enable( m_displayMargin->IsChecked() && (m_foldStyle->GetStringSelection() == _("Arrows with Background Colour") || m_foldStyle->GetStringSelection() == _("Simple with Background Colour")) );
}

void EditorSettingsFolding::OnFoldingMarginUI(wxUpdateUIEvent& event)
{
	event.Enable(m_displayMargin->IsChecked());
}

==> codelite-3.0.0.5041.tar.gz: codelite-3.0.0.5041/LiteEditor/editorsettingsfolding.cpp <==
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////
//
// copyright            : (C) 2008 by Eran Ifrah
// file name            : editorsettingsfolding.cpp
//
// -------------------------------------------------------------------------
// A
//              _____           _      _     _ _
//             /  __ \         | |    | |   (_) |
//             | /  \/ ___   __| | ___| |    _| |_ ___
//             | |    / _ \ / _  |/ _ \ |   | | __/ _ )
//             | \__/\ (_) | (_| |  __/ |___| | ||  __/
//              \____/\___/ \__,_|\___\_____/_|\__\___|
//
//                                                  F i l e
//
//    This program is free software; you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation; either version 2 of the License, or
//    (at your option) any later version.
//
//////////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////////

#include "globals.h"
#include "editorsettingsfolding.h"

EditorSettingsFolding::EditorSettingsFolding( wxWindow* parent )
		: EditorSettingsFoldingBase( parent )
		, TreeBookNode<EditorSettingsFolding>()
{
	OptionsConfigPtr options = EditorConfigST::Get()->GetOptions();
	m_displayMargin->SetValue(options->GetDisplayFoldMargin());
	m_underlineFolded->SetValue(options->GetUnderlineFoldLine());
	m_foldPreprocessors->SetValue(options->GetFoldPreprocessor());
	m_foldCompact->SetValue(options->GetFoldCompact());
	m_foldElse->SetValue(options->GetFoldAtElse());
	
	const wxString FoldStyles[] = { wxTRANSLATE("Simple"), wxTRANSLATE("Arrows"), wxTRANSLATE("Arrows with Background Colour"), wxTRANSLATE("Simple with Background Colour"), 
									  wxTRANSLATE("Flatten Tree Square Headers"), wxTRANSLATE("Flatten Tree Circular Headers") };
	m_stringManager.AddStrings(sizeof(FoldStyles)/sizeof(wxString), FoldStyles, options->GetFoldStyle(), m_foldStyle);

	m_colourPicker->SetColour(options->GetFoldBgColour());
}


void EditorSettingsFolding::Save(OptionsConfigPtr options)
{
	options->SetDisplayFoldMargin(m_displayMargin->GetValue());
	options->SetUnderlineFoldLine(m_underlineFolded->GetValue());
	options->SetFoldPreprocessor(m_foldPreprocessors->GetValue());
	options->SetFoldCompact(m_foldCompact->GetValue());
	options->SetFoldAtElse(m_foldElse->GetValue());
	
	// Get the foldstyle selection, unlocalised
	wxString foldStyle = m_stringManager.GetStringSelection();
	if (foldStyle.IsEmpty()) {
		foldStyle = wxT("Arrows");
	}
	options->SetFoldStyle(foldStyle);
	
	options->SetFoldBgColour(m_colourPicker->GetColour());
}

void EditorSettingsFolding::OnFoldColourUI(wxUpdateUIEvent& e)
{
	e.Enable( m_displayMargin->IsChecked() && (m_foldStyle->GetStringSelection() == _("Arrows with Background Colour") || m_foldStyle->GetStringSelection() == _("Simple with Background Colour")) );
}

void EditorSettingsFolding::OnFoldingMarginUI(wxUpdateUIEvent& event)
{
	event.Enable(m_displayMargin->IsChecked());
}
